;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "dash-functional" "20250312.1307"
  "Collection of useful combinators for Emacs Lisp."
  '((dash "2.18.0"))
  :url "https://github.com/magnars/dash.el"
  :commit "fcb5d831fc08a43f984242c7509870f30983c27c"
  :revdesc "fcb5d831fc08"
  :keywords '("extensions" "lisp")
  :authors '(("Matus Goljer" . "matus.goljer@gmail.com")
             ("Magnar Sveen" . "magnars@gmail.com"))
  :maintainers '(("Matus Goljer" . "matus.goljer@gmail.com")
                 ("Magnar Sveen" . "magnars@gmail.com")))
